Keep markup ▲ Prism plugins

# How to use

You have nothing to do. With this plugin loaded, all markup inside code will be kept.

# Examples

The following source code

    <pre><code class="language-css">
    @media <mark>screen</mark> {
    	div {
    		<mark>text</mark>-decoration: <mark><mark>under</mark>line</mark>;
    		back<mark>ground: url</mark>('foo.png');
    	}
    }</code></pre>

would render like this:

    @media screen {
    	div {
    		text-decoration: underline;
    		background: url('foo.png');
    	}
    }

It also works for inline code: `var bar = function () { /* foo */ };`